#!/usr/bin/env python
import numpy as np
from lineClipping import cohensutherland

"""
make box with corners LL/UR (1,3) (4,5)
and line segment with ends (0,0) (4,6)
"""
#%% LOWER to UPPER test
x1, y1, x2, y2 = cohensutherland(1,  5, 4, 3,
                                 0,  0, 4, 6)

np.testing.assert_array_almost_equal([x1,y1,x2,y2],[2, 3, 3.3333333333333,5])
#%% no intersection test
x1,y1,x2,y2 = cohensutherland(1,5,  4,3,
                              0,0.1,0,0.1)
assert x1==y1==x2==y2==None
#%% left to right test
x1,y1,x2,y2 = cohensutherland(1,5,4,3,
                              0,4,5,4)
np.testing.assert_array_almost_equal([x1,y1,x2,y2],[1, 4, 4, 4])



#!/usr/bin/env python
install_requires = ['numpy']
tests_require=['pytest','nose','coveralls']
# %%
from setuptools import setup,find_packages

setup(name='pylineclip',
      packages=find_packages(),
      description='Line clipping: Cohen-Sutherland',
      long_description=open('README.rst').read(),
      version='0.9.0',
      author='Michael Hirsch, Ph.D.',
      url='https://github.com/scivision/lineclipping-python-fortran',
      classifiers=[
      'Development Status :: 4 - Beta',
      'Environment :: Console',
      'Intended Audience :: Science/Research',
      'License :: OSI Approved :: MIT License',
      'Operating System :: OS Independent',
      'Programming Language :: Python :: 2.7',
      'Programming Language :: Python :: 3.4',
      'Programming Language :: Python :: 3.5',
      'Programming Language :: Python :: 3.6',
      'Programming Language :: Python :: 3.7',
      'Topic :: Scientific/Engineering :: Visualization',
      ],
      install_requires=install_requires,
      tests_require=tests_require,
      extras_require={'tests':tests_require},
      python_requires='>=2.7',
      scripts=['DemoLineclip.py'],
      include_package_data=True,
	  )

